kepi
====

kepi is an ActivityPub daemon.

[ActivityPub](https://www.w3.org/TR/activitypub/) is a standard protocol
for integrating social media across Internet sites.

For example, you might post an article. Someone else on another site
might reply to it, and someone else might "like" it. Someone else again
might "follow" you, in order to get notifications when you post
anything else.

kepi runs in the background on your server, distributing your messages
to other sites, and receiving their responses.

* [Installation guide](docs/installation.md)
* [Source](https://gitlab.com/marnanel/kepi/)

If you'd like to contribute, there's lots to do. Find something on the
[bug tracker](https://gitlab.com/marnanel/kepi/issues?label_name%5B%5D=newbie)
and dive in. If you'd like a gentler learning curve, look
for
[bugs marked "newbie"](https://gitlab.com/marnanel/kepi/issues?label_name%5B%5D=newbie)
